searchData={"items":[{"type":"module","title":"JikanEx","doc":"A thin elixir wrapper for the Jikan API. Start by creating a `JikanEx.client/1`, which is then passed to each request (see `JikanEx.Request`).\n\nYou can set the base url to use in your application configuration:\n\n```\n# config/config.exs\nimport Config\n\nconfig :jikan_ex,\n  base_url: \"http://localhost:8000/v3/\"\n```\n\nIf you're [self-hosting](https://github.com/jikan-me/jikan-rest) an instance of Jikan and have issue connecting to the server, start it so that its accessible from any machine, like:\n\n`php -S 0.0.0.0:25639 -t public`","ref":"JikanEx.html"},{"type":"module","title":"Quickstart - JikanEx","doc":"```\nalias JikanEx.Request\nclient = JikanEx.client()\nresponse = client |> Request.anime!(1)\nIO.puts response[\"title\"]  # Prints 'Cowboy Bebop'\n```\n\nIf you're having JSON-parsing related errors, you may have to recompile `Tesla` with `Jason`, see `Tesla.Middleware.JSON`","ref":"JikanEx.html#module-quickstart"},{"type":"function","title":"JikanEx.client/1","doc":"Creates a new Jikan client. Attempts to get the base url from your application config. If that doesn't exist, uses the remote `api.jikan.moe` endpoint.\n\n\nYou can optionally pass a keyword list with options instead.\n\nReturns `Tesla.Client`","ref":"JikanEx.html#client/1"},{"type":"function","title":"Examples - JikanEx.client/1","doc":"iex> JikanEx.client()\n    %Tesla.Client{\n      adapter: nil,\n      fun: nil,\n      post: [],\n      pre: [{Tesla.Middleware.BaseUrl, :call, [\"https://api.jikan.moe/v3/\"]}]\n    }\n    iex> Application.put_env(:jikan_ex, :base_url, \"http://localhost:8000/v3/\")\n    iex> JikanEx.client()\n    %Tesla.Client{\n      adapter: nil,\n      fun: nil,\n      post: [],\n      pre: [{Tesla.Middleware.BaseUrl, :call, [\"http://localhost:8000/v3/\"]}]\n    }\n    iex> Application.delete_env(:jikan_ex, :base_url)\n    iex> JikanEx.client([base_url: \"http://localhost:8000/v3/\"])\n    %Tesla.Client{\n      adapter: nil,\n      fun: nil,\n      post: [],\n      pre: [{Tesla.Middleware.BaseUrl, :call, [\"http://localhost:8000/v3/\"]}]\n    }","ref":"JikanEx.html#client/1-examples"},{"type":"module","title":"JikanEx.Base","doc":"Creates the Tesla client for Jikan. Encodes/Decodes the JSON response. Called from `JikanEx.client/1`","ref":"JikanEx.Base.html"},{"type":"function","title":"JikanEx.Base.get/3","doc":"Perform a GET request.\n\nSee `request/1` or `request/2` for options definition.\n\n    get(\"/users\")\n    get(\"/users\", query: [scope: \"admin\"])\n    get(client, \"/users\")\n    get(client, \"/users\", query: [scope: \"admin\"])","ref":"JikanEx.Base.html#get/3"},{"type":"function","title":"JikanEx.Base.get!/3","doc":"Perform a GET request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    get!(\"/users\")\n    get!(\"/users\", query: [scope: \"admin\"])\n    get!(client, \"/users\")\n    get!(client, \"/users\", query: [scope: \"admin\"])","ref":"JikanEx.Base.html#get!/3"},{"type":"function","title":"JikanEx.Base.get_base_url/1","doc":"Get the Base Url from a `Tesla.Client`","ref":"JikanEx.Base.html#get_base_url/1"},{"type":"function","title":"Example - JikanEx.Base.get_base_url/1","doc":"iex> client = JikanEx.client()\n    iex> JikanEx.Base.get_base_url(client)\n    \"https://api.jikan.moe/v3/\"\n    iex> client = JikanEx.client([base_url: \"http://localhost:25039/v3/\"])\n    iex> JikanEx.Base.get_base_url(client)\n    \"http://localhost:25039/v3/\"","ref":"JikanEx.Base.html#get_base_url/1-example"},{"type":"function","title":"JikanEx.Base.new/1","doc":"Creates a JikanEx Client. Takes a keyword list as first argument. If the base_url key is missing, uses the default (api.jikan.moe)\n\nThese client that's returned is passed to each request in `JikanEx.Request`.\n\nReturns `Tesla.Client`","ref":"JikanEx.Base.html#new/1"},{"type":"function","title":"Examples - JikanEx.Base.new/1","doc":"iex> JikanEx.Base.new([])\n    iex> JikanEx.Base.new()\n    %Tesla.Client{\n      adapter: nil,\n      fun: nil,\n      post: [],\n      pre: [\n        {Tesla.Middleware.BaseUrl, :call, [\"https://api.jikan.moe/v3/\"]}\n      ]\n    }\n    iex> JikanEx.Base.new([base_url: \"http://localhost:8000/v3/\"])\n    %Tesla.Client{\n      adapter: nil,\n      fun: nil,\n      post: [],\n      pre: [\n        {Tesla.Middleware.BaseUrl, :call, [\"http://localhost:8000/v3/\"]}\n      ]\n    }","ref":"JikanEx.Base.html#new/1-examples"},{"type":"function","title":"JikanEx.Base.request/2","doc":"Perform a request.","ref":"JikanEx.Base.html#request/2"},{"type":"function","title":"Options - JikanEx.Base.request/2","doc":"- `:method` - the request method, one of [:head, :get, :delete, :trace, :options, :post, :put, :patch]\n- `:url` - either full url e.g. \"http://example.com/some/path\" or just \"/some/path\" if using `Tesla.Middleware.BaseUrl`\n- `:query` - a keyword list of query params, e.g. `[page: 1, per_page: 100]`\n- `:headers` - a keyworld list of headers, e.g. `[{\"content-type\", \"text/plain\"}]`\n- `:body` - depends on used middleware:\n    - by default it can be a binary\n    - if using e.g. JSON encoding middleware it can be a nested map\n    - if adapter supports it it can be a Stream with any of the above\n- `:opts` - custom, per-request middleware or adapter options","ref":"JikanEx.Base.html#request/2-options"},{"type":"function","title":"Examples - JikanEx.Base.request/2","doc":"ExampleApi.request(method: :get, url: \"/users/path\")\n\n    # use shortcut methods\n    ExampleApi.get(\"/users/1\")\n    ExampleApi.post(client, \"/users\", %{name: \"Jon\"})","ref":"JikanEx.Base.html#request/2-examples"},{"type":"function","title":"JikanEx.Base.request!/2","doc":"Perform request and raise in case of error.\n\nThis is similar to `request/2` behaviour from Tesla 0.x\n\nSee `request/2` for list of available options.","ref":"JikanEx.Base.html#request!/2"},{"type":"type","title":"JikanEx.Base.option/0","doc":"","ref":"JikanEx.Base.html#t:option/0"},{"type":"module","title":"JikanEx.Request","doc":"Wrapper functions for the corresponding endpoints.\n\nThis does not attempt to rate limit its requests, that could be done naively (through explicit 2 second waits if your application is relatively simple), or by implement a genserver-like queue, see [this thread](https://elixirforum.com/t/how-to-interface-with-a-pool-to-handle-request-throttling/604) for more ideas.\n\nEach function (other than `JikanEx.Request.request/3` and `JikanEx.Request.request!/3`):\n  * accepts:\n    * the client as the first argument\n    * zero or more required arguments as additional individual arguments\n    * (optional) an additional list of URL parts\n    * (optional) a map of GET parameters\n    * (optional) a keyword list of `JikanEx.Request.option`\n  * has a corresponding bang function. Functions without a bang return `{:ok, resp}` or `{:error, resp}`, and raise `Tesla.Error` (inherited from `Tesla`) when a connection couldn't be made, when there was a `Tesla.Adapter` error, or when there was a error decoding the response body. Bang functions raise errors on unsuccessful status codes.\n\nThough functions for each request exist, they're just wrappers for a couple function calls from `JikanEx.Url`:\n\n```\n# for example, building:\n# https://api.jikan.moe/v3/user/nekomata1037/animelist/completed/2?year=2019\nalias JikanEx.Request\nimport JikanEx.Url\n\nclient = JikanEx.client()\n\n# Using JikanEx.Url calls\nresponse = \"user/nekomata1037/\"\n|> paths([:animelist, :completed, 2])\n|> params(:year, 2019)\n|> Request.request!(client)\n\n# same as...\nresponse = Request.user!(client, \"nekomata1037\", [:animelist, :completed, 2], %{year: 2019})\n```\n\nThe response from each function is a map, which includes all the keys which Jikan returned. Additionally, it includes `http_headers`, `http_url` and `http_status`.\n\nA good minority of the Jikan requests don't allow you to pass extra URL parts or GET parameters, but every wrapper function here allows to you to pass a list of paths and a map as optional arguments. This keeps the interface the same for all similar functions.\n\nUsing Jikans [ETag cache validation](https://jikan.docs.apiary.io/#introduction/json-error-response):\n\n```\nalias JikanEx.Request\n\nclient = JikanEx.client()\n\nresponse = Request.anime!(client, 1)\netag = %Tesla.Env{headers: response[\"http_headers\"]} |> Tesla.get_header(\"etag\")\n\n# request using Tesla directly\nnew_response = Tesla.get!(response[\"http_url\"], [headers: [{\"If-None-Match\", etag}]])\n304 = new_response.status\n```","ref":"JikanEx.Request.html"},{"type":"function","title":"JikanEx.Request.anime/5","doc":"Wrapper for the `/anime/` endpoint.","ref":"JikanEx.Request.html#anime/5"},{"type":"function","title":"JikanEx.Request.anime!/5","doc":"Same as `anime/5` but returns the response directly. Raises `JikanEx.Exception` on errors.","ref":"JikanEx.Request.html#anime!/5"},{"type":"function","title":"Example - JikanEx.Request.anime!/5","doc":"iex> response = JikanEx.Request.anime!(client, 26165)\n    iex> response[\"title\"]\n    \"Yuri Kuma Arashi\"\n    iex> response = JikanEx.Request.anime!(client, 11061, [:episodes, 2])\n    iex> response[\"http_url\"]\n    \"https://api.jikan.moe/v3/anime/11061/episodes/2\"","ref":"JikanEx.Request.html#anime!/5-example"},{"type":"function","title":"JikanEx.Request.character/5","doc":"Wrapper for the `/character/` endpoint. Same interface as `anime/5`","ref":"JikanEx.Request.html#character/5"},{"type":"function","title":"JikanEx.Request.character!/5","doc":"Same as `character/5` but returns the response directly. Raises `JikanEx.Exception` on errors.","ref":"JikanEx.Request.html#character!/5"},{"type":"function","title":"Example - JikanEx.Request.character!/5","doc":"iex> response = JikanEx.Request.character!(client, 16)\n    iex> response[\"name\"]\n    \"Edward Wong Hau Pepelu Tivrusky IV\"","ref":"JikanEx.Request.html#character!/5-example"},{"type":"function","title":"JikanEx.Request.club/5","doc":"Wrapper for the `/club/` endpoint. Same interface as `anime/5`","ref":"JikanEx.Request.html#club/5"},{"type":"function","title":"JikanEx.Request.club!/5","doc":"Same as `club/5` but returns the response directly. Raises `JikanEx.Exception` on errors.","ref":"JikanEx.Request.html#club!/5"},{"type":"function","title":"Example - JikanEx.Request.club!/5","doc":"iex> response = JikanEx.Request.club!(client, 72940)\n    iex> response[\"title\"]\n    \"Minna no Uta\"","ref":"JikanEx.Request.html#club!/5-example"},{"type":"function","title":"JikanEx.Request.genre/4","doc":"Wrapper for the `/genre/` endpoint.","ref":"JikanEx.Request.html#genre/4"},{"type":"function","title":"JikanEx.Request.genre!/4","doc":"Same as `genre/5` but returns the response directly. Raises `JikanEx.Exception` on errors.","ref":"JikanEx.Request.html#genre!/4"},{"type":"function","title":"Example - JikanEx.Request.genre!/4","doc":"# first number is the genre ID on MAL, second number is the page\n    iex> response = JikanEx.Request.genre!(client, [:anime, 8, 2])\n    iex> response[\"http_url\"]\n    \"https://api.jikan.moe/v3/genre/anime/8/2\"","ref":"JikanEx.Request.html#genre!/4-example"},{"type":"function","title":"JikanEx.Request.magazine/5","doc":"Wrapper for the `/magazine/` endpoint. Same interface as `anime/5`","ref":"JikanEx.Request.html#magazine/5"},{"type":"function","title":"JikanEx.Request.magazine!/5","doc":"Same as `magazine/5` but returns the response directly. Raises `JikanEx.Exception` on errors.","ref":"JikanEx.Request.html#magazine!/5"},{"type":"function","title":"Example - JikanEx.Request.magazine!/5","doc":"iex> response = JikanEx.Request.magazine!(client, 21)\n    iex> response[\"meta\"][\"name\"]\n    \"Hana to Yume\"","ref":"JikanEx.Request.html#magazine!/5-example"},{"type":"function","title":"JikanEx.Request.manga/5","doc":"Wrapper for the `/manga/` endpoint. Same interface as `anime/5`","ref":"JikanEx.Request.html#manga/5"},{"type":"function","title":"JikanEx.Request.manga!/5","doc":"Same as `manga/5` but returns the response directly. Raises `JikanEx.Exception` on errors.","ref":"JikanEx.Request.html#manga!/5"},{"type":"function","title":"Example - JikanEx.Request.manga!/5","doc":"iex> response = JikanEx.Request.manga!(client, 1, [:characters_staff])\n    iex> response[\"characters\"] |> List.first() |> Map.get(\"name\")\n    \"Liebert, Anna\"","ref":"JikanEx.Request.html#manga!/5-example"},{"type":"function","title":"JikanEx.Request.meta/4","doc":"Wrapper for the `/meta/` endpoint.","ref":"JikanEx.Request.html#meta/4"},{"type":"function","title":"JikanEx.Request.meta!/4","doc":"Same as `meta/5` but returns the response directly. Raises `JikanEx.Exception` on errors.","ref":"JikanEx.Request.html#meta!/4"},{"type":"function","title":"Example - JikanEx.Request.meta!/4","doc":"iex> response = JikanEx.Request.meta!(client, [:requests, :anime, :today])\n    iex> response[\"http_url\"]\n    \"https://api.jikan.moe/v3/meta/requests/anime/today\"","ref":"JikanEx.Request.html#meta!/4-example"},{"type":"function","title":"JikanEx.Request.person/5","doc":"Wrapper for the `/person/` endpoint. Same interface as `anime/5`","ref":"JikanEx.Request.html#person/5"},{"type":"function","title":"JikanEx.Request.person!/5","doc":"Same as `person/5` but returns the response directly. Raises `JikanEx.Exception` on errors.","ref":"JikanEx.Request.html#person!/5"},{"type":"function","title":"Example - JikanEx.Request.person!/5","doc":"iex> response = JikanEx.Request.person!(client, 40135)\n    iex> response[\"url\"]\n    \"https://myanimelist.net/people/40135/Rapparu\"","ref":"JikanEx.Request.html#person!/5-example"},{"type":"function","title":"JikanEx.Request.producer/5","doc":"Wrapper for the `/producer/` endpoint. Same interface as `anime/5`","ref":"JikanEx.Request.html#producer/5"},{"type":"function","title":"JikanEx.Request.producer!/5","doc":"Same as `producer/5` but returns the response directly. Raises `JikanEx.Exception` on errors.","ref":"JikanEx.Request.html#producer!/5"},{"type":"function","title":"Example - JikanEx.Request.producer!/5","doc":"iex> response = JikanEx.Request.producer!(client, 2)\n    iex> response[\"meta\"][\"name\"]\n    \"Kyoto Animation\"","ref":"JikanEx.Request.html#producer!/5-example"},{"type":"function","title":"JikanEx.Request.request/3","doc":"The base request function for the client - all requests eventually call this. Pass a url (`String`) and a `JikanEx.client/1`\n\nReturns `{:ok, response}` on success and `{:error, response}` on error, where `response` is a `Map`","ref":"JikanEx.Request.html#request/3"},{"type":"function","title":"Example - JikanEx.Request.request/3","doc":"iex> case JikanEx.Request.request(\"anime/1\", client) do\n    ...>   {:ok, response}\n    ...>     -> response[\"title\"]\n    ...>   {:error, response}\n    ...>     -> response[\"message\"]\n    ...> end\n    \"Cowboy Bebop\"","ref":"JikanEx.Request.html#request/3-example"},{"type":"function","title":"JikanEx.Request.request!/3","doc":"Same as `request/3`, but returns the response directly. Raises `JikanEx.Exception` on errors.\n    iex> JikanEx.Request.request!(\"anime/1\", client) |> Map.get(\"title\")\n    \"Cowboy Bebop: Tengoku no Tobira\"","ref":"JikanEx.Request.html#request!/3"},{"type":"function","title":"JikanEx.Request.schedule/4","doc":"Wrapper for the `/schedule/` endpoint","ref":"JikanEx.Request.html#schedule/4"},{"type":"function","title":"JikanEx.Request.schedule!/4","doc":"Same as `schedule/5` but returns the response directly. Raises `JikanEx.Exception` on errors.","ref":"JikanEx.Request.html#schedule!/4"},{"type":"function","title":"Example - JikanEx.Request.schedule!/4","doc":"iex> response = JikanEx.Request.schedule!(client, [:monday])\n    iex> response[\"http_url\"]\n    \"https://api.jikan.moe/v3/schedule/monday\"","ref":"JikanEx.Request.html#schedule!/4-example"},{"type":"function","title":"JikanEx.Request.search/4","doc":"Wrapper for the `/search/` endpoint.","ref":"JikanEx.Request.html#search/4"},{"type":"function","title":"JikanEx.Request.search!/4","doc":"Same as `search/5` but returns the response directly. Raises `JikanEx.Exception` on errors.","ref":"JikanEx.Request.html#search!/4"},{"type":"function","title":"Example - JikanEx.Request.search!/4","doc":"iex> response = JikanEx.Request.search!(client, [:anime], %{:q => \"Rakugo Shinjuu\", :page => 1})\n    iex> response[\"results\"] |> List.first() |> Map.get(\"title\")\n    \"Shouwa Genroku Rakugo Shinjuu\"","ref":"JikanEx.Request.html#search!/4-example"},{"type":"function","title":"JikanEx.Request.season/4","doc":"Wrapper for the `/season/`, `/season/archive/` and `/season/later/` endpoints.","ref":"JikanEx.Request.html#season/4"},{"type":"function","title":"JikanEx.Request.season!/4","doc":"Same as `season/5` but returns the response directly. Raises `JikanEx.Exception` on errors.","ref":"JikanEx.Request.html#season!/4"},{"type":"function","title":"Example - JikanEx.Request.season!/4","doc":"iex> response = JikanEx.Request.season!(client, [2020, :winter])\n    iex> response[\"http_url\"]\n    \"https://api.jikan.moe/v3/season/2020/winter\"\n    iex> response = JikanEx.Request.season!(client, [:later])\n    iex> response[\"http_url\"]\n    \"https://api.jikan.moe/v3/season/later\"","ref":"JikanEx.Request.html#season!/4-example"},{"type":"function","title":"JikanEx.Request.top/4","doc":"Wrapper for the `/top/` endpoint.","ref":"JikanEx.Request.html#top/4"},{"type":"function","title":"JikanEx.Request.top!/4","doc":"Same as `top/5` but returns the response directly. Raises `JikanEx.Exception` on errors.","ref":"JikanEx.Request.html#top!/4"},{"type":"function","title":"Example - JikanEx.Request.top!/4","doc":"iex> response = JikanEx.Request.top!(client, [:anime, 1, :airing])\n    iex> response[\"http_url\"]\n    \"https://api.jikan.moe/v3/top/anime/1/airing\"","ref":"JikanEx.Request.html#top!/4-example"},{"type":"function","title":"JikanEx.Request.user/5","doc":"Wrapper for the `/user/` endpoint.","ref":"JikanEx.Request.html#user/5"},{"type":"function","title":"JikanEx.Request.user!/5","doc":"Same as `user/5` but returns the response directly. Raises `JikanEx.Exception` on errors.","ref":"JikanEx.Request.html#user!/5"},{"type":"function","title":"Examples - JikanEx.Request.user!/5","doc":"iex> response = JikanEx.Request.user!(client, \"xinil\", [:animelist, :all, 2], %{year: 2019})\n    iex> response[\"http_url\"]\n    \"https://api.jikan.moe/v3/user/xinil/animelist/all/2?year=2019&\"\n    iex> response = JikanEx.Request.user!(client, \"xinil\")  # request profile\n    iex> response[\"joined\"]\n    \"2004-11-05T00:00:00+00:00\"\n    iex> response = JikanEx.Request.user!(client, \"xinil\", [:friends, 2])\n    iex> response[\"http_url\"]\n    \"https://api.jikan.moe/v3/user/xinil/friends/2\"","ref":"JikanEx.Request.html#user!/5-examples"},{"type":"type","title":"JikanEx.Request.http_response/0","doc":"","ref":"JikanEx.Request.html#t:http_response/0"},{"type":"type","title":"JikanEx.Request.option/0","doc":"","ref":"JikanEx.Request.html#t:option/0"},{"type":"type","title":"JikanEx.Request.response/0","doc":"","ref":"JikanEx.Request.html#t:response/0"},{"type":"module","title":"JikanEx.Url","doc":"Interface to build Jikan URLs. These are then passed onto `JikanEx.Request.request/3`.\n\nIn here, generally, URLs shouldn't start with a slash, and should typically have a slash at the end. The final / is removed when adding query parameters or in `JikanEx.Request.request/3`.","ref":"JikanEx.Url.html"},{"type":"function","title":"JikanEx.Url.page/2","doc":"Add a page number to the URL, calls `JikanEx.Url.path/2`","ref":"JikanEx.Url.html#page/2"},{"type":"function","title":"Example - JikanEx.Url.page/2","doc":"iex> JikanEx.Url.page(\"animelist/all/\", 2)\n    \"animelist/all/2/\"","ref":"JikanEx.Url.html#page/2-example"},{"type":"function","title":"JikanEx.Url.params/2","doc":"Formats a map of GET params into a URL","ref":"JikanEx.Url.html#params/2"},{"type":"function","title":"Example - JikanEx.Url.params/2","doc":"iex> JikanEx.Url.params(\"animelist/all/2\", %{year: 2019, airing_status: \"complete\"})\n    \"animelist/all/2?airing_status=complete&year=2019&\"","ref":"JikanEx.Url.html#params/2-example"},{"type":"function","title":"JikanEx.Url.params/3","doc":"Formats a GET key and value into a URL","ref":"JikanEx.Url.html#params/3"},{"type":"function","title":"Example - JikanEx.Url.params/3","doc":"iex> JikanEx.Url.params(\"animelist/all/2/\", \"year\", 2019)\n    \"animelist/all/2?year=2019&\"","ref":"JikanEx.Url.html#params/3-example"},{"type":"function","title":"JikanEx.Url.path/2","doc":"Add the endpoint (a string, atom, or integer) to the URL","ref":"JikanEx.Url.html#path/2"},{"type":"function","title":"Example - JikanEx.Url.path/2","doc":"iex> JikanEx.Url.path(\"anime/5/\", \"videos\")\n    \"anime/5/videos/\"","ref":"JikanEx.Url.html#path/2-example"},{"type":"function","title":"JikanEx.Url.paths/2","doc":"Adds multiple URL parts (joined by '/') to a URL","ref":"JikanEx.Url.html#paths/2"},{"type":"function","title":"Example - JikanEx.Url.paths/2","doc":"iex> JikanEx.Url.paths(\"anime/\", [1, :character_staff])\n    \"anime/1/character_staff/\"","ref":"JikanEx.Url.html#paths/2-example"},{"type":"function","title":"JikanEx.Url.trim_url/1","doc":"Removes a trailing forward slash from a URL\n\n    iex> JikanEx.Url.trim_url(\"username/animelist/2/\")\n    \"username/animelist/2\"\n    iex> JikanEx.Url.trim_url(\"username/animelist/2\")\n    \"username/animelist/2\"","ref":"JikanEx.Url.html#trim_url/1"},{"type":"type","title":"JikanEx.Url.parameter_key/0","doc":"","ref":"JikanEx.Url.html#t:parameter_key/0"},{"type":"type","title":"JikanEx.Url.parameter_val/0","doc":"","ref":"JikanEx.Url.html#t:parameter_val/0"},{"type":"type","title":"JikanEx.Url.parameters/0","doc":"","ref":"JikanEx.Url.html#t:parameters/0"},{"type":"type","title":"JikanEx.Url.path/0","doc":"","ref":"JikanEx.Url.html#t:path/0"},{"type":"type","title":"JikanEx.Url.url/0","doc":"","ref":"JikanEx.Url.html#t:url/0"},{"type":"module","title":"JikanEx.UrlBuilders","doc":"Creates the URLs for Jikan endpoints. These are called from `JikanEx.Request` and aren't typically used by calling them directly.","ref":"JikanEx.UrlBuilders.html"},{"type":"function","title":"JikanEx.UrlBuilders.build/2","doc":"Builds a URL from a list of paths and a param_map","ref":"JikanEx.UrlBuilders.html#build/2"},{"type":"function","title":"Example - JikanEx.UrlBuilders.build/2","doc":"iex> JikanEx.UrlBuilders.build([:user, \"nekomata1037\", :animelist, :completed, 2], %{year: 2019})\n    \"user/nekomata1037/animelist/completed/2?year=2019&\"","ref":"JikanEx.UrlBuilders.html#build/2-example"},{"type":"function","title":"JikanEx.UrlBuilders.build_url/3","doc":"Similar to `build_url/4` but doesn't accept a MAL ID","ref":"JikanEx.UrlBuilders.html#build_url/3"},{"type":"function","title":"Example - JikanEx.UrlBuilders.build_url/3","doc":"iex> JikanEx.UrlBuilders.build_url({:search!, 0}, [\"anime\"], %{:q => \"k-on\", \"limit\" => 5})\n    \"search/anime?q=k-on&limit=5&\"","ref":"JikanEx.UrlBuilders.html#build_url/3-example"},{"type":"function","title":"JikanEx.UrlBuilders.build_url/4","doc":"Build a URL from a function name, (MAL) id, paths, parameter map\n\nAccepts the `__ENV__.function` from the calling function as the first argument (to turn into the first URL part), the MAL ID for the second and additional paths/params as third/fourth","ref":"JikanEx.UrlBuilders.html#build_url/4"},{"type":"function","title":"Example - JikanEx.UrlBuilders.build_url/4","doc":"iex> JikanEx.UrlBuilders.build_url({:anime!, 0}, 1, [:characters_staff], %{})\n    \"anime/1/characters_staff/\"","ref":"JikanEx.UrlBuilders.html#build_url/4-example"},{"type":"exception","title":"JikanEx.Exception","doc":"Defines the API Error class. It has two fields, a `message` and `response`. `message` is the error message from the Jikan response, and the response is the Response map from `JikanEx.Request`","ref":"JikanEx.Exception.html"},{"type":"function","title":"JikanEx.Exception.exception/1","doc":"Error raised by bang functions in `JikanEx.Request`","ref":"JikanEx.Exception.html#exception/1"},{"type":"extras","title":"JikanEx","doc":"# JikanEx [![Build Status](https://travis-ci.org/purarue/jikan_ex.svg?branch=master)](https://travis-ci.org/purarue/jikan_ex) [![Hex.pm](http://img.shields.io/hexpm/v/jikan_ex.svg?style=flat)](https://hex.pm/packages/jikan_ex) [![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg?style=flat-square)](http://makeapullrequest.com)\n\nA thin elixir wrapper for the [Jikan](https://github.com/jikan-me/jikan) API.\n\nSee the [documentation](https://hexdocs.pm/jikan_ex) for usage.","ref":"readme.html"},{"type":"extras","title":"Quickstart - JikanEx","doc":"```elixir\nalias JikanEx.Request\nclient = JikanEx.client()\nresponse = client |> Request.anime!(1)\nIO.puts response[\"title\"]  # Prints 'Cowboy Bebop'\n```","ref":"readme.html#quickstart"},{"type":"extras","title":"Installation - JikanEx","doc":"Add the following to your `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:jikan_ex, \"~> 0.1.5\"}\n  ]\nend\n```","ref":"readme.html#installation"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}